<?php

namespace Realestate\Property\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Realestate\Property\Events\PropertyAction as PropertyActionEvent;
use Realestate\Property\Notifications\PropertyAction as PropertyActionNotification;
use Litepie\Actions\Concerns\AsAction;

class PropertyAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the PropertyActionEvent.
     *
     * @param   PropertyActionEvent  $event
     * @return mixed
     */
    public function handle(PropertyActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $property.
     *
     * @param   PropertyActionEvent  $event
     * @return void
     */
    public function create(PropertyActionEvent $event)
    {
        $client = $event->property->client;
        Notification::send($client, new PropertyActionNotification($event));
    }

    /**
     * Handle the PropertyActionEvent as a listener.
     *
     * @param   PropertyActionEvent  $event
     * @return mixed
     */
    public function asListener(PropertyActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   PropertyActionEvent  $event
     * @return bool
     */
    private function isAllowed(PropertyActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
